pub enum DevtoolScriptControlMsg {
Show 32 variants
EvaluateJS(PipelineId, String, GenericSender<EvaluateJSReply>),
GetRootNode(PipelineId, GenericSender<Option<NodeInfo>>),
GetDocumentElement(PipelineId, GenericSender<Option<NodeInfo>>),
GetChildren(PipelineId, String, GenericSender<Option<Vec<NodeInfo>>>),
GetAttributeStyle(PipelineId, String, GenericSender<Option<Vec<NodeStyle>>>),
GetStylesheetStyle(PipelineId, String, String, usize, GenericSender<Option<Vec<NodeStyle>>>),
GetSelectors(PipelineId, String, GenericSender<Option<Vec<(String, usize)>>>),
GetComputedStyle(PipelineId, String, GenericSender<Option<Vec<NodeStyle>>>),
GetEventListenerInfo(PipelineId, String, GenericSender<Vec<EventListenerInfo>>),
GetLayout(PipelineId, String, GenericSender<Option<(ComputedNodeLayout, AutoMargins)>>),
GetXPath(PipelineId, String, GenericSender<String>),
ModifyAttribute(PipelineId, String, Vec<AttrModification>),
ModifyRule(PipelineId, String, Vec<RuleModification>),
WantsLiveNotifications(PipelineId, bool),
SetTimelineMarkers(PipelineId, Vec<TimelineMarkerType>, GenericSender<Option<TimelineMarker>>),
DropTimelineMarkers(PipelineId, Vec<TimelineMarkerType>),
RequestAnimationFrame(PipelineId, String),
NavigateTo(PipelineId, ServoUrl),
GoBack(PipelineId),
GoForward(PipelineId),
Reload(PipelineId),
GetCssDatabase(GenericSender<HashMap<String, CssDatabaseProperty>>),
SimulateColorScheme(PipelineId, Theme),
HighlightDomNode(PipelineId, Option<String>),
Eval(String, PipelineId, Option<String>, GenericSender<EvaluateJSReply>),
GetPossibleBreakpoints(u32, GenericSender<Vec<RecommendedBreakpointLocation>>),
SetBreakpoint(u32, u32, u32),
ClearBreakpoint(u32, u32, u32),
Interrupt,
Resume(Option<String>, Option<String>),
ListFrames(PipelineId, u32, u32, GenericSender<Vec<String>>),
GetEnvironment(String, GenericSender<String>),
}Expand description
Messages to process in a particular script thread, as instructed by a devtools client. TODO: better error handling, e.g. if pipeline id lookup fails?
Variants
EvaluateJS(PipelineId, String, GenericSender<EvaluateJSReply>)
Evaluate a JS snippet in the context of the global for the given pipeline.
GetRootNode(PipelineId, GenericSender<Option<NodeInfo>>)
Retrieve the details of the root node (ie. the document) for the given pipeline.
GetDocumentElement(PipelineId, GenericSender<Option<NodeInfo>>)
Retrieve the details of the document element for the given pipeline.
GetChildren(PipelineId, String, GenericSender<Option<Vec<NodeInfo>>>)
Retrieve the details of the child nodes of the given node in the given pipeline.
GetAttributeStyle(PipelineId, String, GenericSender<Option<Vec<NodeStyle>>>)
Retrieve the CSS style properties defined in the attribute tag for the given node.
GetStylesheetStyle(PipelineId, String, String, usize, GenericSender<Option<Vec<NodeStyle>>>)
Retrieve the CSS style properties defined in an stylesheet for the given selector.
GetSelectors(PipelineId, String, GenericSender<Option<Vec<(String, usize)>>>)
Retrieves the CSS selectors for the given node. A selector is comprised of the text of the selector and the id of the stylesheet that contains it.
GetComputedStyle(PipelineId, String, GenericSender<Option<Vec<NodeStyle>>>)
Retrieve the computed CSS style properties for the given node.
GetEventListenerInfo(PipelineId, String, GenericSender<Vec<EventListenerInfo>>)
Get information about event listeners on a node.
GetLayout(PipelineId, String, GenericSender<Option<(ComputedNodeLayout, AutoMargins)>>)
Retrieve the computed layout properties of the given node in the given pipeline.
GetXPath(PipelineId, String, GenericSender<String>)
Get a unique XPath selector for the node.
ModifyAttribute(PipelineId, String, Vec<AttrModification>)
Update a given node’s attributes with a list of modifications.
ModifyRule(PipelineId, String, Vec<RuleModification>)
Update a given node’s style rules with a list of modifications.
WantsLiveNotifications(PipelineId, bool)
Request live console messages for a given pipeline (true if desired, false otherwise).
SetTimelineMarkers(PipelineId, Vec<TimelineMarkerType>, GenericSender<Option<TimelineMarker>>)
Request live notifications for a given set of timeline events for a given pipeline.
DropTimelineMarkers(PipelineId, Vec<TimelineMarkerType>)
Withdraw request for live timeline notifications for a given pipeline.
RequestAnimationFrame(PipelineId, String)
Request a callback directed at the given actor name from the next animation frame executed in the given pipeline.
Direct the WebView containing the given pipeline to load a new URL, as if it was typed by the user.
GoBack(PipelineId)
Direct the WebView containing the given pipeline to traverse history backward up to one step.
GoForward(PipelineId)
Direct the WebView containing the given pipeline to traverse history forward up to one step.
Reload(PipelineId)
Direct the given pipeline to reload the current page.
GetCssDatabase(GenericSender<HashMap<String, CssDatabaseProperty>>)
Gets the list of all allowed CSS rules and possible values.
SimulateColorScheme(PipelineId, Theme)
Simulates a light or dark color scheme for the given pipeline
HighlightDomNode(PipelineId, Option<String>)
Highlight the given DOM node
Eval(String, PipelineId, Option<String>, GenericSender<EvaluateJSReply>)
GetPossibleBreakpoints(u32, GenericSender<Vec<RecommendedBreakpointLocation>>)
SetBreakpoint(u32, u32, u32)
ClearBreakpoint(u32, u32, u32)
Interrupt
Resume(Option<String>, Option<String>)
ListFrames(PipelineId, u32, u32, GenericSender<Vec<String>>)
GetEnvironment(String, GenericSender<String>)